The affected site should be secured utilising the latest and most
secure encryption protocols. These include SSL version 3.0 and TLS
version 1.2. While TLS 1.2 is the latest and the most preferred
protocol, not all browsers will support this encryption method.
Therefore, the more common SSL is included. Older protocols such as
SSL version 2, and weak ciphers (< 128 bit) should also be disabled.